Fraud Eagle Algorithm
=====================

|GPLv3| |Build Status| |Maintainability| |Test Coverage| |Release|
|Japanese|

|Logo|

This package provides an implementation of Fraud Eagle algorithm. This
algorithm has been introduced by Leman Akoglu, *et al.* in `ICWSM
2013 <https://www.aaai.org/ocs/index.php/ICWSM/ICWSM13/paper/viewFile/5981/6338>`__

See `the documents <https://rgmining.github.io/fraud-eagle/>`__ for more
information.

Installation
------------

Use ``pip`` to install this package.

::

    pip install --upgrade rgmining-fraud-eagle

License
-------

This software is released under The GNU General Public License Version
3, see
`COPYING <https://github.com/rgmining/fraud-eagle/blob/master/COPYING>`__
for more detail.

.. |GPLv3| image:: https://img.shields.io/badge/license-GPLv3-blue.svg
   :target: https://www.gnu.org/copyleft/gpl.html
.. |Build Status| image:: https://github.com/rgmining/fraud-eagle/actions/workflows/python-lib.yaml/badge.svg
   :target: https://github.com/rgmining/fraud-eagle/actions/workflows/python-lib.yaml
.. |Maintainability| image:: https://api.codeclimate.com/v1/badges/cf5f0ee2f7f5aa6bd846/maintainability
   :target: https://codeclimate.com/github/rgmining/fraud-eagle/maintainability
.. |Test Coverage| image:: https://api.codeclimate.com/v1/badges/cf5f0ee2f7f5aa6bd846/test_coverage
   :target: https://codeclimate.com/github/rgmining/fraud-eagle/test_coverage
.. |Release| image:: https://img.shields.io/badge/release-0.10.1-brightgreen.svg
   :target: https://pypi.org/project/rgmining-fraud-eagle/
.. |Japanese| image:: https://img.shields.io/badge/qiita-%E6%97%A5%E6%9C%AC%E8%AA%9E-brightgreen.svg
   :target: http://qiita.com/jkawamoto/items/d2284316cc37cd810bfd
.. |Logo| image:: https://rgmining.github.io/fraud-eagle/_static/image.png
   :target: https://rgmining.github.io/fraud-eagle/
